# DataJoint Element - Miniscope Calcium Imaging

DataJoint Element for functional calcium imaging data acquired with the
[UCLA Miniscope](https://github.com/Aharoni-Lab/Miniscope-v4) and
[Miniscope DAQ](https://github.com/Aharoni-Lab/Miniscope-DAQ-QT-Software) acquisition 
system, and analyzed with [CaImAn](https://github.com/flatironinstitute/CaImAn). 
DataJoint Elements collectively standardize and automate data collection and analysis 
for neuroscience experiments. Each Element is a modular pipeline for data storage and 
processing with corresponding database tables that can be combined with other Elements 
to assemble a fully functional pipeline.

## Experiment Flowchart

![flowchart](https://raw.githubusercontent.com/datajoint/element-miniscope/main/images/flowchart.svg)

## Data Pipeline Diagram

![pipeline](https://raw.githubusercontent.com/datajoint/element-miniscope/main/images/pipeline.svg)

## Getting Started

+ Install from PyPI

     ```bash
     pip install element-miniscope
     ```

+ [Interactive tutorial on GitHub Codespaces](https://github.com/datajoint/workflow-miniscope#interactive-tutorial)

+ [Documentation](https://datajoint.com/docs/elements/element-miniscope)

## Support

+ If you need help getting started or run into any errors, please contact our team by email at support@datajoint.com.
